==> haskell-x11-xft-0.3.1-43-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11-xft
version: 0.3.1
id: X11-xft-0.3.1-AMgvCrCGdzgC3OcfXpzTX3
key: X11-xft-0.3.1-AMgvCrCGdzgC3OcfXpzTX3
license: LicenseRef-LGPL
maintainer: clemens@endorphin.org
author: Clemens Fruhwirth
synopsis: Bindings to the Xft, X Free Type interface library, and some Xrender parts
description:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts
category: Graphics
abi: 30f4dd70095bd593d399e436f2a1ff63
exposed: True
exposed-modules:
    Graphics.X11.Xft Graphics.X11.Xrender
import-dirs: /usr/lib/ghc-8.6.5/site-local/X11-xft-0.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/X11-xft-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/X11-xft-0.3.1
hs-libraries: HSX11-xft-0.3.1-AMgvCrCGdzgC3OcfXpzTX3
extra-libraries:
    Xft
include-dirs: /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/uuid
depends:
    X11-1.9-8X00zzCjMe13z8AbgluigM base-4.12.0.0
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html: /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-xft-0.3.1-46-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11-xft
version: 0.3.1
id: X11-xft-0.3.1-451zoDQYu00Jgez6GPDEak
key: X11-xft-0.3.1-451zoDQYu00Jgez6GPDEak
license: LicenseRef-LGPL
maintainer: clemens@endorphin.org
author: Clemens Fruhwirth
synopsis: Bindings to the Xft, X Free Type interface library, and some Xrender parts
description:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts
category: Graphics
abi: 517b31922af74f5f2f3ec229cd6e8669
exposed: True
exposed-modules:
    Graphics.X11.Xft Graphics.X11.Xrender
import-dirs: /usr/lib/ghc-8.6.5/site-local/X11-xft-0.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/X11-xft-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/X11-xft-0.3.1
hs-libraries: HSX11-xft-0.3.1-451zoDQYu00Jgez6GPDEak
extra-libraries:
    Xft
include-dirs: /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include /usr/include/uuid
depends:
    X11-1.9-22zvCDux6sP8dmhhgsoPsT base-4.12.0.0
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html: /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
